pub struct IntegrationsResource { /* private fields */ }Expand description
Integrations — /api/v2/integrations.
Implementations
Sourceimpl IntegrationsResource
impl IntegrationsResource
Sourcepub async fn list_all(&self) -> Result<Vec<Integration>, ManagerError>
pub async fn list_all(&self) -> Result<Vec<Integration>, ManagerError>
List all configured integrations (auto-paginated).
Sourcepub async fn list_page(
&self,
page: i32,
per_page: Option<i32>,
) -> Result<Page<Integration>, ManagerError>
pub async fn list_page( &self, page: i32, per_page: Option<i32>, ) -> Result<Page<Integration>, ManagerError>
List one page of configured integrations.
Sourcepub async fn create(
&self,
body: IntegrationCreateRequest,
) -> Result<IntegrationItemResponse, ManagerError>
pub async fn create( &self, body: IntegrationCreateRequest, ) -> Result<IntegrationItemResponse, ManagerError>
Create an integration.
Sourcepub async fn get(
&self,
id: &str,
) -> Result<IntegrationItemResponse, ManagerError>
pub async fn get( &self, id: &str, ) -> Result<IntegrationItemResponse, ManagerError>
Get an integration by id.
Sourcepub async fn update(
&self,
id: &str,
body: IntegrationUpdateRequest,
) -> Result<IntegrationItemResponse, ManagerError>
pub async fn update( &self, id: &str, body: IntegrationUpdateRequest, ) -> Result<IntegrationItemResponse, ManagerError>
Update an integration.
Sourcepub async fn available(
&self,
) -> Result<IntegrationListAvailableIntegrationsResponse, ManagerError>
pub async fn available( &self, ) -> Result<IntegrationListAvailableIntegrationsResponse, ManagerError>
List the integration providers available to this account.
Sourcepub async fn add_association(
&self,
integration_id: &str,
association_id: &str,
action_name: &str,
) -> Result<IntegrationAddAssociationResponse, ManagerError>
pub async fn add_association( &self, integration_id: &str, association_id: &str, action_name: &str, ) -> Result<IntegrationAddAssociationResponse, ManagerError>
Associate an integration action with an object.
Sourcepub async fn remove_association(
&self,
integration_id: &str,
association_id: &str,
action_name: &str,
) -> Result<IntegrationRemoveAssociationResponse, ManagerError>
pub async fn remove_association( &self, integration_id: &str, association_id: &str, action_name: &str, ) -> Result<IntegrationRemoveAssociationResponse, ManagerError>
Remove an integration action association.
Sourcepub async fn provider_logo(
&self,
provider_name: IntegrationProvider,
size: &str,
) -> Result<GetIntegrationProviderLogoResponse, ManagerError>
pub async fn provider_logo( &self, provider_name: IntegrationProvider, size: &str, ) -> Result<GetIntegrationProviderLogoResponse, ManagerError>
Get a provider’s logo at a given size.
Sourcepub async fn provider_session_variables(
&self,
provider: &str,
) -> Result<IntegrationSessionVariableItemsResponse, ManagerError>
pub async fn provider_session_variables( &self, provider: &str, ) -> Result<IntegrationSessionVariableItemsResponse, ManagerError>
List the session variables a provider’s actions expose.
Sourcepub async fn dispatch_action(
&self,
integration_id: &str,
action: &str,
body: IntegrationDispatchActionRequest,
) -> Result<IntegrationDispatchActionResponse, ManagerError>
pub async fn dispatch_action( &self, integration_id: &str, action: &str, body: IntegrationDispatchActionRequest, ) -> Result<IntegrationDispatchActionResponse, ManagerError>
Dispatch an integration action.
Sourcepub async fn action_variables(
&self,
provider: IntegrationProvider,
action_name: &str,
) -> Result<VariableDefinitionItemsResponse, ManagerError>
pub async fn action_variables( &self, provider: IntegrationProvider, action_name: &str, ) -> Result<VariableDefinitionItemsResponse, ManagerError>
List the variables a single provider action exposes.
Sourcepub async fn providers(
&self,
) -> Result<IntegrationObjectListResponse, ManagerError>
pub async fn providers( &self, ) -> Result<IntegrationObjectListResponse, ManagerError>
List the available integration providers.
Sourcepub async fn provider_template(
&self,
provider: &str,
) -> Result<HashMap<String, Value>, ManagerError>
pub async fn provider_template( &self, provider: &str, ) -> Result<HashMap<String, Value>, ManagerError>
Get a provider’s config template.
Sourcepub async fn template(
&self,
type: &str,
provider: &str,
) -> Result<HashMap<String, Value>, ManagerError>
pub async fn template( &self, type: &str, provider: &str, ) -> Result<HashMap<String, Value>, ManagerError>
Get the config template for a given integration type and provider.
Authorize an integration.
Sourcepub async fn clone(
&self,
id: &str,
) -> Result<IntegrationItemResponse, ManagerError>
pub async fn clone( &self, id: &str, ) -> Result<IntegrationItemResponse, ManagerError>
Clone an integration.
Sourcepub async fn integrate(
&self,
id: &str,
body: HashMap<String, Value>,
) -> Result<IntegrationItemResponse, ManagerError>
pub async fn integrate( &self, id: &str, body: HashMap<String, Value>, ) -> Result<IntegrationItemResponse, ManagerError>
Run the integrate step for an integration.
Sourcepub async fn bulk_update(
&self,
body: BulkUpdateIntegrationsRequest,
) -> Result<DefaultV2MessageResponse, ManagerError>
pub async fn bulk_update( &self, body: BulkUpdateIntegrationsRequest, ) -> Result<DefaultV2MessageResponse, ManagerError>
Update several integrations in one request.
Sourcepub async fn bulk_delete(
&self,
ids: Vec<String>,
) -> Result<DefaultV2MessageResponse, ManagerError>
pub async fn bulk_delete( &self, ids: Vec<String>, ) -> Result<DefaultV2MessageResponse, ManagerError>
Delete several integrations in one request, given their ids.
Sourcepub async fn type_actions(
&self,
type: &str,
) -> Result<IntegrationObjectListResponse, ManagerError>
pub async fn type_actions( &self, type: &str, ) -> Result<IntegrationObjectListResponse, ManagerError>
List the actions exposed by integrations of a given type.
Sourcepub async fn dispatch_type_action(
&self,
type: &str,
id: &str,
action: &str,
body: HashMap<String, Value>,
) -> Result<HashMap<String, Value>, ManagerError>
pub async fn dispatch_type_action( &self, type: &str, id: &str, action: &str, body: HashMap<String, Value>, ) -> Result<HashMap<String, Value>, ManagerError>
Dispatch an action against an integration of a given type.
Sourcepub async fn api_proxy_get(
&self,
integration_id: &str,
uri: &str,
) -> Result<(), ManagerError>
pub async fn api_proxy_get( &self, integration_id: &str, uri: &str, ) -> Result<(), ManagerError>
Proxy a GET request through an integration’s API.
Sourcepub async fn api_proxy_post(
&self,
integration_id: &str,
uri: &str,
body: HashMap<String, Value>,
) -> Result<(), ManagerError>
pub async fn api_proxy_post( &self, integration_id: &str, uri: &str, body: HashMap<String, Value>, ) -> Result<(), ManagerError>
Proxy a POST request through an integration’s API.
Sourcepub async fn list_tokens(
&self,
id: &str,
) -> Result<IntegrationTokenListResponse, ManagerError>
pub async fn list_tokens( &self, id: &str, ) -> Result<IntegrationTokenListResponse, ManagerError>
List the tokens issued for an integration.
Sourcepub async fn get_token(
&self,
id: &str,
token_id: &str,
) -> Result<IntegrationTokenItemResponse, ManagerError>
pub async fn get_token( &self, id: &str, token_id: &str, ) -> Result<IntegrationTokenItemResponse, ManagerError>
Get a single integration token.
Sourcepub async fn delete_token(
&self,
id: &str,
token_id: &str,
) -> Result<DefaultV2MessageResponse, ManagerError>
pub async fn delete_token( &self, id: &str, token_id: &str, ) -> Result<DefaultV2MessageResponse, ManagerError>
Delete an integration token.
Sourcepub async fn refresh_token(
&self,
id: &str,
token_id: &str,
) -> Result<IntegrationTokenItemResponse, ManagerError>
pub async fn refresh_token( &self, id: &str, token_id: &str, ) -> Result<IntegrationTokenItemResponse, ManagerError>
Refresh an integration token.
Sourcepub async fn list_actions(
&self,
type: Option<&str>,
) -> Result<ObjectListResponse, ManagerError>
pub async fn list_actions( &self, type: Option<&str>, ) -> Result<ObjectListResponse, ManagerError>
List the available trigger/automation actions (catalog), optionally filtered by type.
Sourcepub async fn list_action_params(
&self,
provider_name: &str,
provider_action_name: &str,
) -> Result<ObjectListResponse, ManagerError>
pub async fn list_action_params( &self, provider_name: &str, provider_action_name: &str, ) -> Result<ObjectListResponse, ManagerError>
List an action’s input parameters.
Sourcepub async fn execute_action(
&self,
action_type: &str,
action_name: &str,
body: Option<HashMap<String, Value>>,
) -> Result<DefaultV2MessageResponse, ManagerError>
pub async fn execute_action( &self, action_type: &str, action_name: &str, body: Option<HashMap<String, Value>>, ) -> Result<DefaultV2MessageResponse, ManagerError>
Execute a call/queue action directly.
Sourcepub async fn dispatch_action_get(
&self,
integration_id: &str,
action: &str,
call_id: Option<&str>,
session_id: Option<&str>,
) -> Result<IntegrationDispatchActionResponse, ManagerError>
pub async fn dispatch_action_get( &self, integration_id: &str, action: &str, call_id: Option<&str>, session_id: Option<&str>, ) -> Result<IntegrationDispatchActionResponse, ManagerError>
Dispatch an integration action via GET.