pub struct SettingsResource { /* private fields */ }Expand description
Global settings — /api/v2/settings, grouped by scope (app, telephony, audit, ui,
retention). Each section has a read accessor and a set_* writer that return the section’s
typed response.
Implementations
Sourceimpl SettingsResource
impl SettingsResource
Sourcepub async fn app_customer_logging(
&self,
) -> Result<SettingsAppCustomerLoggingResponse, ManagerError>
pub async fn app_customer_logging( &self, ) -> Result<SettingsAppCustomerLoggingResponse, ManagerError>
Read the app customer-logging settings.
Sourcepub async fn set_app_customer_logging(
&self,
body: SettingsAppCustomerLoggingRequest,
) -> Result<SettingsAppCustomerLoggingResponse, ManagerError>
pub async fn set_app_customer_logging( &self, body: SettingsAppCustomerLoggingRequest, ) -> Result<SettingsAppCustomerLoggingResponse, ManagerError>
Update the app customer-logging settings.
Sourcepub async fn app_conversations(
&self,
) -> Result<SettingsAppConversationsResponse, ManagerError>
pub async fn app_conversations( &self, ) -> Result<SettingsAppConversationsResponse, ManagerError>
Read the app conversations settings.
Sourcepub async fn set_app_conversations(
&self,
body: SettingsAppConversationsRequest,
) -> Result<SettingsAppConversationsResponse, ManagerError>
pub async fn set_app_conversations( &self, body: SettingsAppConversationsRequest, ) -> Result<SettingsAppConversationsResponse, ManagerError>
Update the app conversations settings.
Sourcepub async fn app_integrations(
&self,
) -> Result<SettingsAppIntegrationsResponse, ManagerError>
pub async fn app_integrations( &self, ) -> Result<SettingsAppIntegrationsResponse, ManagerError>
Read the app integrations settings.
Sourcepub async fn set_app_integrations(
&self,
body: SettingsAppIntegrationsRequest,
) -> Result<SettingsAppIntegrationsResponse, ManagerError>
pub async fn set_app_integrations( &self, body: SettingsAppIntegrationsRequest, ) -> Result<SettingsAppIntegrationsResponse, ManagerError>
Update the app integrations settings.
Sourcepub async fn app_agent_status(
&self,
) -> Result<SettingsAppAgentStatusResponse, ManagerError>
pub async fn app_agent_status( &self, ) -> Result<SettingsAppAgentStatusResponse, ManagerError>
Read the app agent-status settings.
Sourcepub async fn set_app_agent_status(
&self,
body: SettingsAppAgentStatusRequest,
) -> Result<SettingsAppAgentStatusResponse, ManagerError>
pub async fn set_app_agent_status( &self, body: SettingsAppAgentStatusRequest, ) -> Result<SettingsAppAgentStatusResponse, ManagerError>
Update the app agent-status settings.
Sourcepub async fn telephony_agent_inbound(
&self,
) -> Result<SettingsTelephonyAgentInboundResponse, ManagerError>
pub async fn telephony_agent_inbound( &self, ) -> Result<SettingsTelephonyAgentInboundResponse, ManagerError>
Read the telephony agent-inbound settings.
Sourcepub async fn set_telephony_agent_inbound(
&self,
body: SettingsTelephonyAgentInboundRequest,
) -> Result<SettingsTelephonyAgentInboundResponse, ManagerError>
pub async fn set_telephony_agent_inbound( &self, body: SettingsTelephonyAgentInboundRequest, ) -> Result<SettingsTelephonyAgentInboundResponse, ManagerError>
Update the telephony agent-inbound settings.
Sourcepub async fn telephony_agent_outbound(
&self,
) -> Result<SettingsTelephonyAgentOutboundResponse, ManagerError>
pub async fn telephony_agent_outbound( &self, ) -> Result<SettingsTelephonyAgentOutboundResponse, ManagerError>
Read the telephony agent-outbound settings.
Sourcepub async fn set_telephony_agent_outbound(
&self,
body: SettingsTelephonyAgentOutboundRequest,
) -> Result<SettingsTelephonyAgentOutboundResponse, ManagerError>
pub async fn set_telephony_agent_outbound( &self, body: SettingsTelephonyAgentOutboundRequest, ) -> Result<SettingsTelephonyAgentOutboundResponse, ManagerError>
Update the telephony agent-outbound settings.
Sourcepub async fn telephony_agent_recording(
&self,
) -> Result<SettingsTelephonyAgentRecordingResponse, ManagerError>
pub async fn telephony_agent_recording( &self, ) -> Result<SettingsTelephonyAgentRecordingResponse, ManagerError>
Read the telephony agent-recording settings.
Sourcepub async fn set_telephony_agent_recording(
&self,
body: SettingsTelephonyAgentRecordingRequest,
) -> Result<SettingsTelephonyAgentRecordingResponse, ManagerError>
pub async fn set_telephony_agent_recording( &self, body: SettingsTelephonyAgentRecordingRequest, ) -> Result<SettingsTelephonyAgentRecordingResponse, ManagerError>
Update the telephony agent-recording settings.
Sourcepub async fn telephony_agent_wrapup(
&self,
) -> Result<SettingsTelephonyAgentWrapupResponse, ManagerError>
pub async fn telephony_agent_wrapup( &self, ) -> Result<SettingsTelephonyAgentWrapupResponse, ManagerError>
Read the telephony agent-wrapup settings.
Sourcepub async fn set_telephony_agent_wrapup(
&self,
body: SettingsTelephonyAgentWrapupRequest,
) -> Result<SettingsTelephonyAgentWrapupResponse, ManagerError>
pub async fn set_telephony_agent_wrapup( &self, body: SettingsTelephonyAgentWrapupRequest, ) -> Result<SettingsTelephonyAgentWrapupResponse, ManagerError>
Update the telephony agent-wrapup settings.
Sourcepub async fn telephony_post_call(
&self,
) -> Result<SettingsTelephonyPostCallResponse, ManagerError>
pub async fn telephony_post_call( &self, ) -> Result<SettingsTelephonyPostCallResponse, ManagerError>
Read the telephony post-call settings.
Sourcepub async fn set_telephony_post_call(
&self,
body: SettingsTelephonyPostCallRequest,
) -> Result<SettingsTelephonyPostCallResponse, ManagerError>
pub async fn set_telephony_post_call( &self, body: SettingsTelephonyPostCallRequest, ) -> Result<SettingsTelephonyPostCallResponse, ManagerError>
Update the telephony post-call settings.
Sourcepub async fn audit_default(
&self,
) -> Result<SettingsAuditDefaultResponse, ManagerError>
pub async fn audit_default( &self, ) -> Result<SettingsAuditDefaultResponse, ManagerError>
Read the audit default settings.
Sourcepub async fn set_audit_default(
&self,
body: SettingsAuditDefaultRequest,
) -> Result<SettingsAuditDefaultResponse, ManagerError>
pub async fn set_audit_default( &self, body: SettingsAuditDefaultRequest, ) -> Result<SettingsAuditDefaultResponse, ManagerError>
Update the audit default settings.
Sourcepub async fn ui_i18n(&self) -> Result<SettingsUiI18nResponse, ManagerError>
pub async fn ui_i18n(&self) -> Result<SettingsUiI18nResponse, ManagerError>
Read the UI i18n settings.
Sourcepub async fn set_ui_i18n(
&self,
body: SettingsUiI18nRequest,
) -> Result<SettingsUiI18nResponse, ManagerError>
pub async fn set_ui_i18n( &self, body: SettingsUiI18nRequest, ) -> Result<SettingsUiI18nResponse, ManagerError>
Update the UI i18n settings.
Sourcepub async fn retention_periods(
&self,
) -> Result<SettingsRetentionPeriodsResponse, ManagerError>
pub async fn retention_periods( &self, ) -> Result<SettingsRetentionPeriodsResponse, ManagerError>
Read the retention periods settings.
Sourcepub async fn set_retention_periods(
&self,
body: SettingsRetentionPeriodsRequest,
) -> Result<SettingsRetentionPeriodsResponse, ManagerError>
pub async fn set_retention_periods( &self, body: SettingsRetentionPeriodsRequest, ) -> Result<SettingsRetentionPeriodsResponse, ManagerError>
Update the retention periods settings.
Sourcepub async fn list_all(&self) -> Result<SettingsListResponse, ManagerError>
pub async fn list_all(&self) -> Result<SettingsListResponse, ManagerError>
List every customer setting across all scopes.
Sourcepub async fn list_in_scope(
&self,
scope: &str,
) -> Result<SettingsListResponse, ManagerError>
pub async fn list_in_scope( &self, scope: &str, ) -> Result<SettingsListResponse, ManagerError>
List all customer settings in a scope.
Sourcepub async fn clear(
&self,
scope: &str,
key: &str,
) -> Result<SettingItemResponse, ManagerError>
pub async fn clear( &self, scope: &str, key: &str, ) -> Result<SettingItemResponse, ManagerError>
Reset a single setting to its default.
Sourcepub async fn clear_in_scope(
&self,
scope: &str,
) -> Result<SettingsListResponse, ManagerError>
pub async fn clear_in_scope( &self, scope: &str, ) -> Result<SettingsListResponse, ManagerError>
Reset all settings in a scope to their defaults.
Sourcepub async fn clear_all(&self) -> Result<SettingsListResponse, ManagerError>
pub async fn clear_all(&self) -> Result<SettingsListResponse, ManagerError>
Reset every customer setting across all scopes to their defaults.